from django.core.management.base import BaseCommand
from django.apps import apps
from django.db.migrations.loader import MigrationLoader
from django.db import connection
from django_migration_resolver.utils import get_latest_migration, update_latest_migration, \
    get_migration_file_path, update_migration_dependencies


class Command(BaseCommand):
    help = "Resolve migration conflicts by adjusting dependencies."

    def handle(self, *args, **options):
        loader = MigrationLoader(connection)
        for app in apps.get_app_configs():
            previous_latest_migration = get_latest_migration(app.name)

            if not previous_latest_migration:
                continue

            update_latest_migration(app.name)
            new_latest_migration = get_latest_migration(app.name)

            if not new_latest_migration:
                continue

            migration_file_path = get_migration_file_path(app.name, new_latest_migration)

            if not migration_file_path.exists():
                self.stdout.write(f"Migration file {new_latest_migration} not found for {app.name}.")
                continue

            leaf_nodes = loader.graph.leaf_nodes(app.name)

            if len(leaf_nodes) <= 1:
                continue

            update_migration_dependencies(app.name, new_latest_migration, leaf_nodes, migration_file_path)

            self.stdout.write(f"Updated {new_latest_migration} for {app.name}.")